.. _configuration:

 .. important::::
     ``DEFAULT`` config is the parent of all other configurations and others will inherit its values if not overridden

.. click:: hckr.cli.configure:configure
   :prog: hckr configure
   :nested: full
